summaryrefslogtreecommitdiff
path: root/IvyProbe
diff options
context:
space:
mode:
authorfcolin2007-02-01 13:12:28 +0000
committerfcolin2007-02-01 13:12:28 +0000
commit637e738039ec3f4a76d492516d767ef791e3758e (patch)
tree0a423a2c6e8f2b3b64e8c862905f4aee4a113e7f /IvyProbe
parent501bc7c837b0d6d77d7e5d073020ac20fbd1c02a (diff)
downloadivy-cplusplus-637e738039ec3f4a76d492516d767ef791e3758e.zip
ivy-cplusplus-637e738039ec3f4a76d492516d767ef791e3758e.tar.gz
ivy-cplusplus-637e738039ec3f4a76d492516d767ef791e3758e.tar.bz2
ivy-cplusplus-637e738039ec3f4a76d492516d767ef791e3758e.tar.xz
Utilisateur : Fcolin Date : 2/02/01 Heure : 18:30 Archivé dans $/Bus/Test Commentaire: win CE compile not finished (vss 2)
Diffstat (limited to 'IvyProbe')
-rw-r--r--IvyProbe/TestParseCmdLine.cpp39
1 files changed, 11 insertions, 28 deletions
diff --git a/IvyProbe/TestParseCmdLine.cpp b/IvyProbe/TestParseCmdLine.cpp
index 6b9201e..62eff43 100644
--- a/IvyProbe/TestParseCmdLine.cpp
+++ b/IvyProbe/TestParseCmdLine.cpp
@@ -1,10 +1,10 @@
// FxParseCmdLine.cpp: implementation of the FxParseCmdLine class.
//
//////////////////////////////////////////////////////////////////////
#include "stdafx.h"
-#include "NewFxServer.h"
-#include "FxParseCmdLine.h"
+
+#include "TestParseCmdLine.h"
#ifdef _DEBUG
#undef THIS_FILE
@@ -16,22 +16,18 @@ static char THIS_FILE[]=__FILE__;
// Construction/Destruction
//////////////////////////////////////////////////////////////////////
-FxParseCmdLine::FxParseCmdLine()
+TestParseCmdLine::TestParseCmdLine()
{
- m_loop = FALSE;
m_start = FALSE;
- m_busstart = FALSE;
- m_speed = 10000;
- m_exoFile = "D:\\users\\fcolin\\DATA\\SceTobago.toc";
m_busNumber = "";
}
-FxParseCmdLine::~FxParseCmdLine()
+TestParseCmdLine::~TestParseCmdLine()
{
}
-void FxParseCmdLine::ParseParam(LPCTSTR lpszParam, BOOL bFlag, BOOL bLast)
+void TestParseCmdLine::ParseParam(LPCTSTR lpszParam, BOOL bFlag, BOOL bLast)
{
if (bFlag)
{
@@ -42,34 +38,21 @@ void FxParseCmdLine::ParseParam(LPCTSTR lpszParam, BOOL bFlag, BOOL bLast)
}
-void FxParseCmdLine::ParseParamFlag(LPCTSTR pszParam)
+void TestParseCmdLine::ParseParamFlag(LPCTSTR pszParam)
{
- if (lstrcmpi(pszParam, "loop") == 0)
- m_loop = TRUE;
- else if (lstrcmpi(pszParam, "busstart") == 0)
- m_busstart = TRUE;
- else if (lstrcmpi(pszParam, "start") == 0)
+
+ if (lstrcmpi(pszParam, TEXT("start")) == 0)
m_start = TRUE;
- else if (lstrcmpi(pszParam, "bus") == 0)
+ else if (lstrcmpi(pszParam, TEXT("bus")) == 0)
m_shellCommand = BusNumber;
- else if (lstrcmpi(pszParam, "file") == 0)
- m_shellCommand = ExoFile;
- else if (lstrcmpi(pszParam, "speed") == 0)
- m_shellCommand = Speed;
}
-void FxParseCmdLine::ParseParamNotFlag(LPCTSTR pszParam)
+void TestParseCmdLine::ParseParamNotFlag(LPCTSTR pszParam)
{
switch ( m_shellCommand )
{
case BusNumber:
m_busNumber = pszParam;
break;
- case ExoFile:
- m_exoFile = pszParam;
- break;
- case Speed:
- m_speed = atoi(pszParam);
- break;
}
}
@@ -1,10 +1,10 @@
-// FxParseCmdLine.cpp: implementation of the FxParseCmdLine class.
+// TestParseCmdLine.cpp: implementation of the TestParseCmdLine class.
//
//////////////////////////////////////////////////////////////////////